summaryrefslogtreecommitdiffstats
path: root/kword/KWDocument.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-19 11:38:41 -0600
committerTimothy Pearson <[email protected]>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /kword/KWDocument.cpp
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kword/KWDocument.cpp')
-rw-r--r--kword/KWDocument.cpp46
1 files changed, 23 insertions, 23 deletions
diff --git a/kword/KWDocument.cpp b/kword/KWDocument.cpp
index 5a60f326..271359ba 100644
--- a/kword/KWDocument.cpp
+++ b/kword/KWDocument.cpp
@@ -643,7 +643,7 @@ void KWDocument::setPageLayout( const KoPageLayout& tqlayout, const KoColumns& c
if ( updateViews )
{
// Invalidate document tqlayout, for proper tqrepaint
this->tqlayout();
emit pageLayoutChanged( m_pageLayout );
updateContentsSize();
@@ -996,7 +996,7 @@ void KWDocument::recalcFrames( int fromPage, int toPage /*-1 for all*/, uint fla
bool KWDocument::loadChildren( KoStore *store )
{
//kdDebug(32001) << "KWDocument::loadChildren" << endl;
- TQPtrListIterator<KoDocumentChild> it( tqchildren() );
+ TQPtrListIterator<KoDocumentChild> it( children() );
for( ; it.current(); ++it ) {
if ( !it.current()->loadDocument( store ) )
return FALSE;
@@ -1060,7 +1060,7 @@ bool KWDocument::loadOasis( const TQDomDocument& doc, KoOasisStyles& oasisStyles
if ( localName.isEmpty() )
setErrorMessage( i18n( "Invalid OASIS OpenDocument file. No tag found inside office:body." ) );
else
- setErrorMessage( i18n( "This is not a word processing document, but %1. Please try opening it with the appropriate application." ).tqarg( KoDocument::tagNameToDocumentType( localName ) ) );
+ setErrorMessage( i18n( "This is not a word processing document, but %1. Please try opening it with the appropriate application." ).arg( KoDocument::tagNameToDocumentType( localName ) ) );
return false;
}
@@ -1141,7 +1141,7 @@ bool KWDocument::loadOasis( const TQDomDocument& doc, KoOasisStyles& oasisStyles
styleStack.setTypeProperties( "page-tqlayout" );
frame->loadBorderProperties( styleStack );
}
- fs->renumberFootNotes( false /*no tqrepaint*/ );
+ fs->renumberFootNotes( false /*no repaint*/ );
} else {
// DTP mode: the items in the body are page-sequence and then frames
@@ -1309,7 +1309,7 @@ bool KWDocument::loadMasterPageStyle( const TQString& masterPageName, KoOasisCon
if ( properties.hasAttributeNS( "http://www.w3.org/1999/XSL/Format", "page-width" ) )
setErrorMessage( i18n( "Invalid document. 'fo' has the wrong namespace. The application which produced this document is not OASIS-compliant." ) );
else
- setErrorMessage( i18n( "Invalid document. Paper size: %1x%2" ).tqarg( m_pageLayout.ptWidth ).tqarg( m_pageLayout.ptHeight ) );
+ setErrorMessage( i18n( "Invalid document. Paper size: %1x%2" ).arg( m_pageLayout.ptWidth ).arg( m_pageLayout.ptHeight ) );
return false;
}
@@ -1484,7 +1484,7 @@ bool KWDocument::loadXML( TQIODevice *, const TQDomDocument & doc )
else if ( value != "application/x-kword" && value != "application/vnd.kde.kword" )
{
kdError(32001) << "Unknown mime type " << value << endl;
- setErrorMessage( i18n( "Invalid document. Expected mimetype application/x-kword or application/vnd.kde.kword, got %1" ).tqarg( value ) );
+ setErrorMessage( i18n( "Invalid document. Expected mimetype application/x-kword or application/vnd.kde.kword, got %1" ).arg( value ) );
return false;
}
m_syntaxVersion = KWDocument::getAttribute( word, "syntaxVersion", 0 );
@@ -1492,7 +1492,7 @@ bool KWDocument::loadXML( TQIODevice *, const TQDomDocument & doc )
{
int ret = KMessageBox::warningContinueCancel(
0, i18n("This document was created with a newer version of KWord (syntax version: %1)\n"
- "Opening it in this version of KWord will lose some information.").tqarg(m_syntaxVersion),
+ "Opening it in this version of KWord will lose some information.").arg(m_syntaxVersion),
i18n("File Format Mismatch"), KStdGuiItem::cont() );
if ( ret == KMessageBox::Cancel )
{
@@ -1535,7 +1535,7 @@ bool KWDocument::loadXML( TQIODevice *, const TQDomDocument & doc )
if ( pgLayout.ptWidth <= 0 || pgLayout.ptHeight <= 0 )
{
setErrorMessage( i18n( "Invalid document. Paper size: %1x%2" )
- .tqarg( pgLayout.ptWidth ).tqarg( pgLayout.ptHeight ) );
+ .arg( pgLayout.ptWidth ).arg( pgLayout.ptHeight ) );
return false;
}
}
@@ -1928,7 +1928,7 @@ void KWDocument::endOfLoading() // called by both oasis and oldxml
// Renumber footnotes
KWTextFrameSet *frameset = dynamic_cast<KWTextFrameSet *>( m_lstFrameSet.getFirst() );
if ( frameset )
- frameset->renumberFootNotes( false /*no tqrepaint*/ );
+ frameset->renumberFootNotes( false /*no repaint*/ );
emit sigProgress(-1);
@@ -2499,7 +2499,7 @@ void KWDocument::processAnchorRequests()
KWFrameSet * fs = frameSetByName( fsname );
Q_ASSERT( fs );
if ( fs )
- fs->setAnchored( itanch.data().textfs, itanch.data().paragId, itanch.data().index, true, false /*don't tqrepaint yet*/ );
+ fs->setAnchored( itanch.data().textfs, itanch.data().paragId, itanch.data().index, true, false /*don't repaint yet*/ );
}
m_anchorRequests.clear();
}
@@ -2533,7 +2533,7 @@ bool KWDocument::processFootNoteRequests()
if ( ret ) {
KWFrameSet *frameset = m_lstFrameSet.getFirst();
if ( frameset && frameset->type() == FT_TEXT )
- static_cast<KWTextFrameSet *>(frameset)->renumberFootNotes( false /*no tqrepaint*/ );
+ static_cast<KWTextFrameSet *>(frameset)->renumberFootNotes( false /*no repaint*/ );
}
return ret;
}
@@ -2545,13 +2545,13 @@ TQString KWDocument::uniqueFramesetName( const TQString& oldName )
{
// make up a new name for the frameset, use Copy[digits]-[oldname] as template.
// Fully translatable naturally :)
- TQString searchString( "^(" + i18n("Copy%1-%2").tqarg("\\d*").tqarg("){0,1}") );
+ TQString searchString( "^(" + i18n("Copy%1-%2").arg("\\d*").arg("){0,1}") );
searchString = searchString.replace(TQRegExp("\\-"), "\\-"); // escape the '-'
TQRegExp searcher(searchString);
int count=0;
do {
newName=oldName;
- newName.replace(searcher,i18n("Copy%1-%2").tqarg(count > 0? TQString("%1").tqarg(count):"").tqarg(""));
+ newName.replace(searcher,i18n("Copy%1-%2").arg(count > 0? TQString("%1").arg(count):"").arg(""));
count++;
} while ( frameSetByName( newName ) );
}
@@ -2762,7 +2762,7 @@ void KWDocument::insertEmbedded( KoStore *store, TQDomElement topElem, KMacroCom
kdDebug() << "KWDocument::insertEmbedded loading embedded object" << endl;
part->load( settings );
if ( offset != 0 ) {
- TQRect r = ch->tqgeometry();
+ TQRect r = ch->geometry();
r.moveBy( (int)offset, (int)offset );
ch->setGeometry( r );
}
@@ -3601,7 +3601,7 @@ TQDomDocument KWDocument::saveXML()
}
// Save embedded objects
- saveEmbeddedObjects( kwdoc, tqchildren() );
+ saveEmbeddedObjects( kwdoc, children() );
return doc;
}
@@ -3811,7 +3811,7 @@ TQPixmap KWDocument::generatePreview( const TQSize& size )
double oldZoomY = zoomedResolutionY();
// Sometimes (due to the different resolution?) the tqlayout creates a new page
// while saving the preview. If this happens, we don't want to tqrepaint the real views
// (due to KWCanvas::slotNewContentsSize)
// ##### One day when we have real doc/view separation in kotextparag, we shouldn't mess with
// the real view's resolution, we should instead create a fake view for the preview itself.
@@ -3887,7 +3887,7 @@ KWPartFrameSet* KWDocument::insertObject( const KoRect& rect, KoDocumentEntry& e
KWCreateFrameCommand *cmd = new KWCreateFrameCommand( i18n("Create Part Frame"), frame);
addCommand(cmd);
- frameChanged( frame ); // tqrepaint etc.
+ frameChanged( frame ); // repaint etc.
return frameset;
}
@@ -4210,7 +4210,7 @@ TQString KWDocument::generateFramesetName( const TQString & templateName )
int num = 1;
bool exists;
do {
- name = templateName.tqarg( num );
+ name = templateName.arg( num );
exists = frameSetByName( name );
++num;
} while ( exists );
@@ -4568,12 +4568,12 @@ void KWDocument::tqlayout()
it.current()->tqlayout();
}
-void KWDocument::tqinvalidate(const KWFrameSet *skipThisFrameSet)
+void KWDocument::invalidate(const KWFrameSet *skipThisFrameSet)
{
TQPtrListIterator<KWFrameSet> it = framesetsIterator();
for (; it.current(); ++it )
if(it.current()!=skipThisFrameSet)
- it.current()->tqinvalidate();
+ it.current()->invalidate();
}
KFormula::Document* KWDocument::formulaDocument( bool init )
@@ -4835,7 +4835,7 @@ void KWDocument::slotChapterParagraphFormatted( KoTextParag* /*parag*/ )
{
// Attempt at invalidating from the parag's page only
// But that's not good enough - if a header gets moved down,
// we also need to tqinvalidate the previous page, from where the paragraph disappeared.
/*
KoPoint p;
KWFrame* frame = internalToDocument( parag->rect().topLeft(), p );
@@ -5033,7 +5033,7 @@ void KWDocument::displayFootNoteFieldCode()
KoTextParag * parag = it.current()->paragraph();
if ( parag )
{
- parag->tqinvalidate( 0 );
+ parag->invalidate( 0 );
parag->setChanged( true );
}
}
@@ -5058,7 +5058,7 @@ void KWDocument::changeFootNoteConfig()
KoTextParag * parag = footNoteVar->paragraph();
if ( parag )
{
- parag->tqinvalidate( 0 );
+ parag->invalidate( 0 );
parag->setChanged( true );
}
KoTextDocument* textdoc = parag->textDocument();
@@ -643,7 +643,7 @@ void KWDocument::setPageLayout( const KoPageLayout& tqlayout, const KoColumns& c
if ( updateViews )
{
- // Invalidate document tqlayout, for proper tqrepaint
+ // Invalidate document tqlayout, for proper repaint
this->tqlayout();
emit pageLayoutChanged( m_pageLayout );
@@ -3811,7 +3811,7 @@ TQPixmap KWDocument::generatePreview( const TQSize& size )
double oldZoomY = zoomedResolutionY();
// Sometimes (due to the different resolution?) the tqlayout creates a new page
- // while saving the preview. If this happens, we don't want to tqrepaint the real views
+ // while saving the preview. If this happens, we don't want to repaint the real views
// (due to KWCanvas::slotNewContentsSize)
// ##### One day when we have real doc/view separation in kotextparag, we shouldn't mess with
@@ -4835,7 +4835,7 @@ void KWDocument::slotChapterParagraphFormatted( KoTextParag* /*parag*/ )
// Attempt at invalidating from the parag's page only
// But that's not good enough - if a header gets moved down,
- // we also need to tqinvalidate the previous page, from where the paragraph disappeared.
+ // we also need to invalidate the previous page, from where the paragraph disappeared.
/*
KoPoint p;